# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/ranker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ranker import activity_pb2 as eolymp_dot_ranker_dot_activity__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/ranker/activity.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x84\x01\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\x12\x1b\n\x13\x61\x64\x64_default_columns\x18\x02 \x01(\x08\x12\x1f\n\x17\x64uplicate_scoreboard_id\x18\x03 \x01(\t\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\xdf\x01\n\x15UpdateScoreboardInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.ranker.UpdateScoreboardInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12-\n\nscoreboard\x18\x03 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"E\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x10\n\x0c\x44\x45\x46\x41ULT_SORT\x10\x03\x12\x0e\n\nHISTORICAL\x10\x04\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\".\n\x17RebuildScoreboardOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"H\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xa7\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x93\x01\n\x1a\x44\x65scribeScoreboardRowInput\x12\x34\n\x04mode\x18\n \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x0b \x01(\r\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"Y\n\x1b\x44\x65scribeScoreboardRowOutput\x12*\n\x03row\x18\x01 \x01(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"\xd3\x04\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.ranker.ListScoreboardRowsInput.Filter\x12\x0c\n\x04sort\x18\x32 \x01(\t\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xb4\x01\n\x10\x45xpressionColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x06string\x18\n \x01(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x06number\x18\x0b \x01(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12.\n\x04\x65num\x18\x0c \x01(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x1a\x84\x01\n\x06\x46ilter\x12\x31\n\tmember_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12G\n\x06\x63olumn\x18\x02 \x03(\x0b\x32\x37.eolymp.ranker.ListScoreboardRowsInput.ExpressionColumn\"g\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"c\n\x18\x41\x64\x64ScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\".\n\x19\x41\x64\x64ScoreboardColumnOutput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"\xb4\x02\n\x1bUpdateScoreboardColumnInput\x12?\n\x05patch\x18\x01 \x03(\x0e\x32\x30.eolymp.ranker.UpdateScoreboardColumnInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12\x11\n\tcolumn_id\x18\x03 \x01(\t\x12\x30\n\x06\x63olumn\x18\x04 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"x\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\r\n\tPARENT_ID\x10\x01\x12\x07\n\x03KEY\x10\x02\x12\x08\n\x04NAME\x10\x03\x12\x0e\n\nSHORT_NAME\x10\x04\x12\t\n\x05INDEX\x10\x05\x12\x0b\n\x07VISIBLE\x10\x06\x12\x0e\n\nFILTERABLE\x10\x07\x12\x0c\n\x08SORTABLE\x10\x08\"\x1e\n\x1cUpdateScoreboardColumnOutput\"G\n\x1b\x44\x65leteScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteScoreboardColumnOutput\"I\n\x1d\x44\x65scribeScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"R\n\x1e\x44\x65scribeScoreboardColumnOutput\x12\x30\n\x06\x63olumn\x18\x01 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"3\n\x1aListScoreboardColumnsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x1bListScoreboardColumnsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"J\n\x13ListActivitiesInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.ranker.Activity\"^\n\x13ScheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Action\")\n\x14ScheduleActionOutput\x12\x11\n\taction_id\x18\x01 \x01(\t\"A\n\x15UnscheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\taction_id\x18\x02 \x01(\t\"\x18\n\x16UnscheduleActionOutput\"2\n\x19ListScheduledActionsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\\\n\x1aListScheduledActionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Action2\xfe\x19\n\x06Ranker\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16UpdateScoreboardColumn\x12*.eolymp.ranker.UpdateScoreboardColumnInput\x1a+.eolymp.ranker.UpdateScoreboardColumnOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32\x1a\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columns\x12\xb3\x01\n\x0eListActivities\x12\".eolymp.ranker.ListActivitiesInput\x1a#.eolymp.ranker.ListActivitiesOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02)\x12\'/scoreboards/{scoreboard_id}/activities\x12\xb6\x01\n\x0eScheduleAction\x12\".eolymp.ranker.ScheduleActionInput\x1a#.eolymp.ranker.ScheduleActionOutput\"[\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\"%/scoreboards/{scoreboard_id}/schedule\x12\xc8\x01\n\x10UnscheduleAction\x12$.eolymp.ranker.UnscheduleActionInput\x1a%.eolymp.ranker.UnscheduleActionOutput\"g\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x33*1/scoreboards/{scoreboard_id}/schedule/{action_id}\x12\xc8\x01\n\x14ListScheduledActions\x12(.eolymp.ranker.ListScheduledActionsInput\x1a).eolymp.ranker.ListScheduledActionsOutput\"[\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\'\x12%/scoreboards/{scoreboard_id}/scheduleB/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.ranker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _RANKER.methods_by_name['CreateScoreboard']._options = None
  _RANKER.methods_by_name['CreateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\"\014/scoreboards'
  _RANKER.methods_by_name['UpdateScoreboard']._options = None
  _RANKER.methods_by_name['UpdateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['RebuildScoreboard']._options = None
  _RANKER.methods_by_name['RebuildScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _RANKER.methods_by_name['DeleteScoreboard']._options = None
  _RANKER.methods_by_name['DeleteScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['DescribeScoreboard']._options = None
  _RANKER.methods_by_name['DescribeScoreboard']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['ListScoreboards']._options = None
  _RANKER.methods_by_name['ListScoreboards']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\022\014/scoreboards'
  _RANKER.methods_by_name['DescribeScoreboardRow']._options = None
  _RANKER.methods_by_name['DescribeScoreboardRow']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _RANKER.methods_by_name['ListScoreboardRows']._options = None
  _RANKER.methods_by_name['ListScoreboardRows']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _RANKER.methods_by_name['AddScoreboardColumn']._options = None
  _RANKER.methods_by_name['AddScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['UpdateScoreboardColumn']._options = None
  _RANKER.methods_by_name['UpdateScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022\0320/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['DeleteScoreboardColumn']._options = None
  _RANKER.methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['DescribeScoreboardColumn']._options = None
  _RANKER.methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['ListScoreboardColumns']._options = None
  _RANKER.methods_by_name['ListScoreboardColumns']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['ListActivities']._options = None
  _RANKER.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002)\022\'/scoreboards/{scoreboard_id}/activities'
  _RANKER.methods_by_name['ScheduleAction']._options = None
  _RANKER.methods_by_name['ScheduleAction']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\'\"%/scoreboards/{scoreboard_id}/schedule'
  _RANKER.methods_by_name['UnscheduleAction']._options = None
  _RANKER.methods_by_name['UnscheduleAction']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0023*1/scoreboards/{scoreboard_id}/schedule/{action_id}'
  _RANKER.methods_by_name['ListScheduledActions']._options = None
  _RANKER.methods_by_name['ListScheduledActions']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\'\022%/scoreboards/{scoreboard_id}/schedule'
  _CREATESCOREBOARDINPUT._serialized_start=276
  _CREATESCOREBOARDINPUT._serialized_end=408
  _CREATESCOREBOARDOUTPUT._serialized_start=410
  _CREATESCOREBOARDOUTPUT._serialized_end=457
  _UPDATESCOREBOARDINPUT._serialized_start=460
  _UPDATESCOREBOARDINPUT._serialized_end=683
  _UPDATESCOREBOARDINPUT_PATCH._serialized_start=614
  _UPDATESCOREBOARDINPUT_PATCH._serialized_end=683
  _UPDATESCOREBOARDOUTPUT._serialized_start=685
  _UPDATESCOREBOARDOUTPUT._serialized_end=709
  _REBUILDSCOREBOARDINPUT._serialized_start=711
  _REBUILDSCOREBOARDINPUT._serialized_end=758
  _REBUILDSCOREBOARDOUTPUT._serialized_start=760
  _REBUILDSCOREBOARDOUTPUT._serialized_end=806
  _DELETESCOREBOARDINPUT._serialized_start=808
  _DELETESCOREBOARDINPUT._serialized_end=854
  _DELETESCOREBOARDOUTPUT._serialized_start=856
  _DELETESCOREBOARDOUTPUT._serialized_end=880
  _DESCRIBESCOREBOARDINPUT._serialized_start=882
  _DESCRIBESCOREBOARDINPUT._serialized_end=954
  _DESCRIBESCOREBOARDOUTPUT._serialized_start=956
  _DESCRIBESCOREBOARDOUTPUT._serialized_end=1029
  _LISTSCOREBOARDSINPUT._serialized_start=1032
  _LISTSCOREBOARDSINPUT._serialized_end=1199
  _LISTSCOREBOARDSINPUT_FILTER._serialized_start=1147
  _LISTSCOREBOARDSINPUT_FILTER._serialized_end=1199
  _LISTSCOREBOARDSOUTPUT._serialized_start=1201
  _LISTSCOREBOARDSOUTPUT._serialized_end=1281
  _DESCRIBESCOREBOARDROWINPUT._serialized_start=1284
  _DESCRIBESCOREBOARDROWINPUT._serialized_end=1431
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_start=1433
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_end=1522
  _LISTSCOREBOARDROWSINPUT._serialized_start=1525
  _LISTSCOREBOARDROWSINPUT._serialized_end=2120
  _LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN._serialized_start=1805
  _LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN._serialized_end=1985
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_start=1988
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_end=2120
  _LISTSCOREBOARDROWSOUTPUT._serialized_start=2122
  _LISTSCOREBOARDROWSOUTPUT._serialized_end=2225
  _ADDSCOREBOARDCOLUMNINPUT._serialized_start=2227
  _ADDSCOREBOARDCOLUMNINPUT._serialized_end=2326
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_start=2328
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_end=2374
  _UPDATESCOREBOARDCOLUMNINPUT._serialized_start=2377
  _UPDATESCOREBOARDCOLUMNINPUT._serialized_end=2685
  _UPDATESCOREBOARDCOLUMNINPUT_PATCH._serialized_start=2565
  _UPDATESCOREBOARDCOLUMNINPUT_PATCH._serialized_end=2685
  _UPDATESCOREBOARDCOLUMNOUTPUT._serialized_start=2687
  _UPDATESCOREBOARDCOLUMNOUTPUT._serialized_end=2717
  _DELETESCOREBOARDCOLUMNINPUT._serialized_start=2719
  _DELETESCOREBOARDCOLUMNINPUT._serialized_end=2790
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_start=2792
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_end=2822
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_start=2824
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_end=2897
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_start=2899
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_end=2981
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_start=2983
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_end=3034
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_start=3036
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_end=3129
  _LISTACTIVITIESINPUT._serialized_start=3131
  _LISTACTIVITIESINPUT._serialized_end=3205
  _LISTACTIVITIESOUTPUT._serialized_start=3207
  _LISTACTIVITIESOUTPUT._serialized_end=3284
  _SCHEDULEACTIONINPUT._serialized_start=3286
  _SCHEDULEACTIONINPUT._serialized_end=3380
  _SCHEDULEACTIONOUTPUT._serialized_start=3382
  _SCHEDULEACTIONOUTPUT._serialized_end=3423
  _UNSCHEDULEACTIONINPUT._serialized_start=3425
  _UNSCHEDULEACTIONINPUT._serialized_end=3490
  _UNSCHEDULEACTIONOUTPUT._serialized_start=3492
  _UNSCHEDULEACTIONOUTPUT._serialized_end=3516
  _LISTSCHEDULEDACTIONSINPUT._serialized_start=3518
  _LISTSCHEDULEDACTIONSINPUT._serialized_end=3568
  _LISTSCHEDULEDACTIONSOUTPUT._serialized_start=3570
  _LISTSCHEDULEDACTIONSOUTPUT._serialized_end=3662
  _RANKER._serialized_start=3665
  _RANKER._serialized_end=6991
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Course(_message.Message):
    __slots__ = ["description", "duration", "estimate", "id", "image_url", "locale", "name", "topics", "url", "visibility"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_RENDER: Course.Extra
    DESCRIPTION_VALUE: Course.Extra
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ESTIMATE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRIVATE: Course.Visibility
    PUBLIC: Course.Visibility
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EXTRA: Course.Extra
    UNKNOWN_VISIBILITY: Course.Visibility
    UNLISTED: Course.Visibility
    URL_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    description: _content_pb2.Content
    duration: int
    estimate: int
    id: str
    image_url: str
    locale: str
    name: str
    topics: _containers.RepeatedScalarFieldContainer[str]
    url: str
    visibility: Course.Visibility
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., locale: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., image_url: _Optional[str] = ..., visibility: _Optional[_Union[Course.Visibility, str]] = ..., duration: _Optional[int] = ..., topics: _Optional[_Iterable[str]] = ..., estimate: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/configuration_idp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/community/configuration_idp.proto\x12\x10\x65olymp.community\"\xdd\x02\n\x10IdentityProvider\x1a\n\n\x08\x42\x61secamp\x1a~\n\x05Local\x12\x1d\n\x15\x61llow_modify_nickname\x18\x01 \x01(\x08\x12\x1b\n\x13\x61llow_modify_basics\x18\x02 \x01(\x08\x12\x1a\n\x12\x61llow_modify_email\x18\x03 \x01(\x08\x12\x1d\n\x15\x61llow_modify_password\x18\x04 \x01(\x08\x1a\xbc\x01\n\x04OIDC\x12\x11\n\tclient_id\x18\n \x01(\t\x12\x15\n\rclient_secret\x18\x0b \x01(\t\x12\x0e\n\x06issuer\x18\x14 \x01(\t\x12\x1a\n\x12\x61uthorize_endpoint\x18\x15 \x01(\t\x12\x16\n\x0etoken_endpoint\x18\x16 \x01(\t\x12\x15\n\rkeys_endpoint\x18\x17 \x01(\t\x12\x19\n\x11userinfo_endpoint\x18\x18 \x01(\t\x12\x14\n\x0credirect_uri\x18\x19 \x01(\tB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.configuration_idp_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _IDENTITYPROVIDER._serialized_start=63
  _IDENTITYPROVIDER._serialized_end=412
  _IDENTITYPROVIDER_BASECAMP._serialized_start=83
  _IDENTITYPROVIDER_BASECAMP._serialized_end=93
  _IDENTITYPROVIDER_LOCAL._serialized_start=95
  _IDENTITYPROVIDER_LOCAL._serialized_end=221
  _IDENTITYPROVIDER_OIDC._serialized_start=224
  _IDENTITYPROVIDER_OIDC._serialized_end=412
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Test(_message.Message):
    __slots__ = ["answer_generator", "answer_url", "example", "example_answer_url", "example_input_url", "generated_answer_url", "generated_input_url", "id", "inactive", "index", "input_generator", "input_url", "score", "secret", "testset_id"]
    class Generator(_message.Message):
        __slots__ = ["arguments", "script_name"]
        ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
        SCRIPT_NAME_FIELD_NUMBER: _ClassVar[int]
        arguments: _containers.RepeatedScalarFieldContainer[str]
        script_name: str
        def __init__(self, script_name: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ...) -> None: ...
    ANSWER_GENERATOR_FIELD_NUMBER: _ClassVar[int]
    ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_INPUT_URL_FIELD_NUMBER: _ClassVar[int]
    GENERATED_ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
    GENERATED_INPUT_URL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    INPUT_GENERATOR_FIELD_NUMBER: _ClassVar[int]
    INPUT_URL_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    answer_generator: Test.Generator
    answer_url: str
    example: bool
    example_answer_url: str
    example_input_url: str
    generated_answer_url: str
    generated_input_url: str
    id: str
    inactive: bool
    index: int
    input_generator: Test.Generator
    input_url: str
    score: float
    secret: bool
    testset_id: str
    def __init__(self, id: _Optional[str] = ..., testset_id: _Optional[str] = ..., index: _Optional[int] = ..., example: bool = ..., inactive: bool = ..., secret: bool = ..., score: _Optional[float] = ..., example_input_url: _Optional[str] = ..., example_answer_url: _Optional[str] = ..., generated_input_url: _Optional[str] = ..., generated_answer_url: _Optional[str] = ..., input_url: _Optional[str] = ..., input_generator: _Optional[_Union[Test.Generator, _Mapping]] = ..., answer_url: _Optional[str] = ..., answer_generator: _Optional[_Union[Test.Generator, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AppendStreamInput(_message.Message):
    __slots__ = ["data", "offset", "stream_id"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    offset: int
    stream_id: str
    def __init__(self, stream_id: _Optional[str] = ..., offset: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class AppendStreamOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CloseStreamInput(_message.Message):
    __slots__ = ["stream_id"]
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    stream_id: str
    def __init__(self, stream_id: _Optional[str] = ...) -> None: ...

class CloseStreamOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CompleteMultipartUploadInput(_message.Message):
    __slots__ = ["parts", "upload_id"]
    class Part(_message.Message):
        __slots__ = ["checksum_md5", "checksum_sha1", "checksum_sha256", "number", "token"]
        CHECKSUM_MD5_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_SHA1_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_SHA256_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        TOKEN_FIELD_NUMBER: _ClassVar[int]
        checksum_md5: str
        checksum_sha1: str
        checksum_sha256: str
        number: int
        token: str
        def __init__(self, number: _Optional[int] = ..., token: _Optional[str] = ..., checksum_md5: _Optional[str] = ..., checksum_sha1: _Optional[str] = ..., checksum_sha256: _Optional[str] = ...) -> None: ...
    PARTS_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    parts: _containers.RepeatedCompositeFieldContainer[CompleteMultipartUploadInput.Part]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., parts: _Optional[_Iterable[_Union[CompleteMultipartUploadInput.Part, _Mapping]]] = ...) -> None: ...

class CompleteMultipartUploadOutput(_message.Message):
    __slots__ = ["asset_url"]
    ASSET_URL_FIELD_NUMBER: _ClassVar[int]
    asset_url: str
    def __init__(self, asset_url: _Optional[str] = ...) -> None: ...

class LookupAssetInput(_message.Message):
    __slots__ = ["key"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class LookupAssetOutput(_message.Message):
    __slots__ = ["asset_url"]
    ASSET_URL_FIELD_NUMBER: _ClassVar[int]
    asset_url: str
    def __init__(self, asset_url: _Optional[str] = ...) -> None: ...

class StartMultipartUploadInput(_message.Message):
    __slots__ = ["keys", "name", "ttl", "type"]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TTL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedScalarFieldContainer[str]
    name: str
    ttl: int
    type: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., keys: _Optional[_Iterable[str]] = ..., ttl: _Optional[int] = ...) -> None: ...

class StartMultipartUploadOutput(_message.Message):
    __slots__ = ["upload_id"]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ...) -> None: ...

class StartStreamInput(_message.Message):
    __slots__ = ["name", "ttl", "type"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TTL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    ttl: int
    type: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., ttl: _Optional[int] = ...) -> None: ...

class StartStreamOutput(_message.Message):
    __slots__ = ["stream_id", "stream_url"]
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    STREAM_URL_FIELD_NUMBER: _ClassVar[int]
    stream_id: str
    stream_url: str
    def __init__(self, stream_id: _Optional[str] = ..., stream_url: _Optional[str] = ...) -> None: ...

class UploadAssetInput(_message.Message):
    __slots__ = ["data", "keys", "name", "ttl", "type"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TTL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    keys: _containers.RepeatedScalarFieldContainer[str]
    name: str
    ttl: int
    type: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., keys: _Optional[_Iterable[str]] = ..., ttl: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadAssetOutput(_message.Message):
    __slots__ = ["asset_url"]
    ASSET_URL_FIELD_NUMBER: _ClassVar[int]
    asset_url: str
    def __init__(self, asset_url: _Optional[str] = ...) -> None: ...

class UploadFileInput(_message.Message):
    __slots__ = ["data", "name", "type"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    name: str
    type: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadFileOutput(_message.Message):
    __slots__ = ["file_url"]
    FILE_URL_FIELD_NUMBER: _ClassVar[int]
    file_url: str
    def __init__(self, file_url: _Optional[str] = ...) -> None: ...

class UploadImageInput(_message.Message):
    __slots__ = ["crop", "data", "name", "size", "type", "variants"]
    class Crop(_message.Message):
        __slots__ = ["bottom", "left", "right", "top"]
        BOTTOM_FIELD_NUMBER: _ClassVar[int]
        LEFT_FIELD_NUMBER: _ClassVar[int]
        RIGHT_FIELD_NUMBER: _ClassVar[int]
        TOP_FIELD_NUMBER: _ClassVar[int]
        bottom: int
        left: int
        right: int
        top: int
        def __init__(self, top: _Optional[int] = ..., right: _Optional[int] = ..., bottom: _Optional[int] = ..., left: _Optional[int] = ...) -> None: ...
    class Size(_message.Message):
        __slots__ = ["height", "width"]
        HEIGHT_FIELD_NUMBER: _ClassVar[int]
        WIDTH_FIELD_NUMBER: _ClassVar[int]
        height: int
        width: int
        def __init__(self, width: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...
    CROP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    crop: UploadImageInput.Crop
    data: bytes
    name: str
    size: UploadImageInput.Size
    type: str
    variants: _containers.RepeatedCompositeFieldContainer[UploadImageInput.Size]
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., crop: _Optional[_Union[UploadImageInput.Crop, _Mapping]] = ..., size: _Optional[_Union[UploadImageInput.Size, _Mapping]] = ..., variants: _Optional[_Iterable[_Union[UploadImageInput.Size, _Mapping]]] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadImageOutput(_message.Message):
    __slots__ = ["image_url"]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    image_url: str
    def __init__(self, image_url: _Optional[str] = ...) -> None: ...

class UploadPartInput(_message.Message):
    __slots__ = ["data", "part_number", "upload_id"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    part_number: int
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., part_number: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadPartOutput(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import submission_pb2 as _submission_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSubmissionInput(_message.Message):
    __slots__ = ["lang", "problem_id", "source"]
    LANG_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    lang: str
    problem_id: str
    source: str
    def __init__(self, problem_id: _Optional[str] = ..., lang: _Optional[str] = ..., source: _Optional[str] = ...) -> None: ...

class CreateSubmissionOutput(_message.Message):
    __slots__ = ["submission_id"]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    def __init__(self, submission_id: _Optional[str] = ...) -> None: ...

class DescribeSubmissionInput(_message.Message):
    __slots__ = ["submission_id"]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    def __init__(self, submission_id: _Optional[str] = ...) -> None: ...

class DescribeSubmissionOutput(_message.Message):
    __slots__ = ["extra", "submission"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_submission_pb2.Submission.Extra]
    submission: _submission_pb2.Submission
    def __init__(self, submission: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_submission_pb2.Submission.Extra, str]]] = ...) -> None: ...

class DescribeSubmissionUsageInput(_message.Message):
    __slots__ = ["period_end", "period_start"]
    PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    PERIOD_START_FIELD_NUMBER: _ClassVar[int]
    period_end: _timestamp_pb2.Timestamp
    period_start: _timestamp_pb2.Timestamp
    def __init__(self, period_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DescribeSubmissionUsageOutput(_message.Message):
    __slots__ = ["available_evaluations", "monthly_evaluations", "monthly_submissions", "total_submissions"]
    AVAILABLE_EVALUATIONS_FIELD_NUMBER: _ClassVar[int]
    MONTHLY_EVALUATIONS_FIELD_NUMBER: _ClassVar[int]
    MONTHLY_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SUBMISSIONS_FIELD_NUMBER: _ClassVar[int]
    available_evaluations: int
    monthly_evaluations: int
    monthly_submissions: int
    total_submissions: int
    def __init__(self, total_submissions: _Optional[int] = ..., monthly_submissions: _Optional[int] = ..., monthly_evaluations: _Optional[int] = ..., available_evaluations: _Optional[int] = ...) -> None: ...

class ListProblemTopInput(_message.Message):
    __slots__ = ["problem_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class ListProblemTopOutput(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    def __init__(self, items: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ...) -> None: ...

class ListSubmissionsInput(_message.Message):
    __slots__ = ["after", "extra", "filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "member_id", "percentage", "problem_id", "runtime", "score", "status", "submitted_at", "user_id", "verdict"]
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        SUBMITTED_AT_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        VERDICT_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        percentage: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionFloat]
        problem_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        runtime: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        score: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionFloat]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        submitted_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        user_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        verdict: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., problem_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., user_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., submitted_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., runtime: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., verdict: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., score: _Optional[_Iterable[_Union[_expression_pb2.ExpressionFloat, _Mapping]]] = ..., percentage: _Optional[_Iterable[_Union[_expression_pb2.ExpressionFloat, _Mapping]]] = ...) -> None: ...
    AFTER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    after: str
    extra: _containers.RepeatedScalarFieldContainer[_submission_pb2.Submission.Extra]
    filters: ListSubmissionsInput.Filter
    offset: int
    size: int
    def __init__(self, after: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListSubmissionsInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_submission_pb2.Submission.Extra, str]]] = ...) -> None: ...

class ListSubmissionsOutput(_message.Message):
    __slots__ = ["items", "next_page_cursor", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    next_page_cursor: str
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ..., next_page_cursor: _Optional[str] = ...) -> None: ...

class RetestSubmissionInput(_message.Message):
    __slots__ = ["debug", "submission_id"]
    DEBUG_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    debug: bool
    submission_id: str
    def __init__(self, submission_id: _Optional[str] = ..., debug: bool = ...) -> None: ...

class RetestSubmissionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SubmissionChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _submission_pb2.Submission
    before: _submission_pb2.Submission
    def __init__(self, before: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ..., after: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ...) -> None: ...

class SubmissionCompleteEvent(_message.Message):
    __slots__ = ["submission", "update"]
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    UPDATE_FIELD_NUMBER: _ClassVar[int]
    submission: _submission_pb2.Submission
    update: bool
    def __init__(self, submission: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ..., update: bool = ...) -> None: ...

class WatchSubmissionInput(_message.Message):
    __slots__ = ["extra", "submission_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_submission_pb2.Submission.Extra]
    submission_id: str
    def __init__(self, submission_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_submission_pb2.Submission.Extra, str]]] = ...) -> None: ...

class WatchSubmissionOutput(_message.Message):
    __slots__ = ["submission"]
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    submission: _submission_pb2.Submission
    def __init__(self, submission: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/problem_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import code_template_pb2 as eolymp_dot_atlas_dot_code__template__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.course import submission_service_pb2 as eolymp_dot_course_dot_submission__service__pb2
from eolymp.playground import run_pb2 as eolymp_dot_playground_dot_run__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/course/problem_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/atlas/code_template.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a&eolymp/course/submission_service.proto\x1a\x1b\x65olymp/playground/run.proto\x1a\x1c\x65olymp/runtime/runtime.proto\"\x15\n\x13ListStatementsInput\"M\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Statement\"\x13\n\x11ListExamplesInput\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"*\n\x17LookupCodeTemplateInput\x12\x0f\n\x07runtime\x18\x01 \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\"e\n\x0e\x43reateRunInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x64 \x01(\t\x12\x14\n\ninput_data\x18\x65 \x01(\x0cH\x00\x12\x13\n\tinput_ref\x18\x66 \x01(\tH\x00\x42\x07\n\x05input\"!\n\x0f\x43reateRunOutput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"8\n\x11\x44\x65scribeRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run\"\x1f\n\rWatchRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"5\n\x0eWatchRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run\"\x13\n\x11ListRuntimesInput\"K\n\x12ListRuntimesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime2\x95\r\n\x0eProblemService\x12\x97\x01\n\x0eListStatements\x12\".eolymp.course.ListStatementsInput\x1a#.eolymp.course.ListStatementsOutput\"<\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\x12\x0b/statements\x12\x8f\x01\n\x0cListExamples\x12 .eolymp.course.ListExamplesInput\x1a!.eolymp.course.ListExamplesOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/examples\x12\xa0\x01\n\x10\x43reateSubmission\x12$.eolymp.course.CreateSubmissionInput\x1a%.eolymp.course.CreateSubmissionOutput\"?\x82\xe3\n\x18\x8a\xe3\n\x14\x63ourse:course:submit\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0e\"\x0c/submissions\x12\x9b\x01\n\x0fListSubmissions\x12#.eolymp.course.ListSubmissionsInput\x1a$.eolymp.course.ListSubmissionsOutput\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xb4\x01\n\x12\x44\x65scribeSubmission\x12&.eolymp.course.DescribeSubmissionInput\x1a\'.eolymp.course.DescribeSubmissionOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12z\n\x0fWatchSubmission\x12#.eolymp.course.WatchSubmissionInput\x1a$.eolymp.course.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read0\x01\x12\xa1\x01\n\x12LookupCodeTemplate\x12&.eolymp.course.LookupCodeTemplateInput\x1a\'.eolymp.course.LookupCodeTemplateOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\x12\t/template\x12\x84\x01\n\tCreateRun\x12\x1d.eolymp.course.CreateRunInput\x1a\x1e.eolymp.course.CreateRunOutput\"8\x82\xe3\n\x18\x8a\xe3\n\x14playground:run:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/runs\x12\x92\x01\n\x0b\x44\x65scribeRun\x12\x1f.eolymp.course.DescribeRunInput\x1a .eolymp.course.DescribeRunOutput\"@\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10\x12\x0e/runs/{run_id}\x12\x91\x01\n\x08WatchRun\x12\x1c.eolymp.course.WatchRunInput\x1a\x1d.eolymp.course.WatchRunOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x16\x12\x14/runs/{run_id}/watch0\x01\x12\x8e\x01\n\x0cListRuntimes\x12 .eolymp.course.ListRuntimesInput\x1a!.eolymp.course.ListRuntimesOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x19\x82\xd3\xe4\x93\x02\n\x12\x08/runtimeB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.problem_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _PROBLEMSERVICE.methods_by_name['ListStatements']._options = None
  _PROBLEMSERVICE.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\022\013/statements'
  _PROBLEMSERVICE.methods_by_name['ListExamples']._options = None
  _PROBLEMSERVICE.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/examples'
  _PROBLEMSERVICE.methods_by_name['CreateSubmission']._options = None
  _PROBLEMSERVICE.methods_by_name['CreateSubmission']._serialized_options = b'\202\343\n\030\212\343\n\024course:course:submit\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002\016\"\014/submissions'
  _PROBLEMSERVICE.methods_by_name['ListSubmissions']._options = None
  _PROBLEMSERVICE.methods_by_name['ListSubmissions']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\022\014/submissions'
  _PROBLEMSERVICE.methods_by_name['DescribeSubmission']._options = None
  _PROBLEMSERVICE.methods_by_name['DescribeSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _PROBLEMSERVICE.methods_by_name['WatchSubmission']._options = None
  _PROBLEMSERVICE.methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read'
  _PROBLEMSERVICE.methods_by_name['LookupCodeTemplate']._options = None
  _PROBLEMSERVICE.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\013\022\t/template'
  _PROBLEMSERVICE.methods_by_name['CreateRun']._options = None
  _PROBLEMSERVICE.methods_by_name['CreateRun']._serialized_options = b'\202\343\n\030\212\343\n\024playground:run:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\007\"\005/runs'
  _PROBLEMSERVICE.methods_by_name['DescribeRun']._options = None
  _PROBLEMSERVICE.methods_by_name['DescribeRun']._serialized_options = b'\202\343\n\027\212\343\n\023playground:run:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\020\022\016/runs/{run_id}'
  _PROBLEMSERVICE.methods_by_name['WatchRun']._options = None
  _PROBLEMSERVICE.methods_by_name['WatchRun']._serialized_options = b'\202\343\n\027\212\343\n\023playground:run:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\026\022\024/runs/{run_id}/watch'
  _PROBLEMSERVICE.methods_by_name['ListRuntimes']._options = None
  _PROBLEMSERVICE.methods_by_name['ListRuntimes']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\031\202\323\344\223\002\n\022\010/runtime'
  _LISTSTATEMENTSINPUT._serialized_start=349
  _LISTSTATEMENTSINPUT._serialized_end=370
  _LISTSTATEMENTSOUTPUT._serialized_start=372
  _LISTSTATEMENTSOUTPUT._serialized_end=449
  _LISTEXAMPLESINPUT._serialized_start=451
  _LISTEXAMPLESINPUT._serialized_end=470
  _LISTEXAMPLESOUTPUT._serialized_start=472
  _LISTEXAMPLESOUTPUT._serialized_end=530
  _LOOKUPCODETEMPLATEINPUT._serialized_start=532
  _LOOKUPCODETEMPLATEINPUT._serialized_end=574
  _LOOKUPCODETEMPLATEOUTPUT._serialized_start=576
  _LOOKUPCODETEMPLATEOUTPUT._serialized_end=644
  _CREATERUNINPUT._serialized_start=646
  _CREATERUNINPUT._serialized_end=747
  _CREATERUNOUTPUT._serialized_start=749
  _CREATERUNOUTPUT._serialized_end=782
  _DESCRIBERUNINPUT._serialized_start=784
  _DESCRIBERUNINPUT._serialized_end=818
  _DESCRIBERUNOUTPUT._serialized_start=820
  _DESCRIBERUNOUTPUT._serialized_end=876
  _WATCHRUNINPUT._serialized_start=878
  _WATCHRUNINPUT._serialized_end=909
  _WATCHRUNOUTPUT._serialized_start=911
  _WATCHRUNOUTPUT._serialized_end=964
  _LISTRUNTIMESINPUT._serialized_start=966
  _LISTRUNTIMESINPUT._serialized_end=985
  _LISTRUNTIMESOUTPUT._serialized_start=987
  _LISTRUNTIMESOUTPUT._serialized_end=1062
  _PROBLEMSERVICE._serialized_start=1065
  _PROBLEMSERVICE._serialized_end=2750
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/version.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/atlas/version.proto\x12\x0c\x65olymp.atlas\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa1\x01\n\x07Version\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0e\n\x06number\x18\x01 \x01(\r\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x11\n\tchange_op\x18\x04 \x01(\t\x12\x13\n\x0b\x63hange_path\x18\x05 \x01(\t\x12\x0e\n\x06\x63ursor\x18\x64 \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.version_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _VERSION._serialized_start=78
  _VERSION._serialized_end=239
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/message_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import message_pb2 as eolymp_dot_discussion_dot_message__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/discussion/message_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/discussion/message.proto\x1a\x18\x65olymp/ecm/content.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"|\n\x13MessageChangedEvent\x12*\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12)\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12\x0e\n\x06reason\x18\x03 \x01(\t\"l\n\x14\x44\x65scribeMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.discussion.Message.Extra\"D\n\x15\x44\x65scribeMessageOutput\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\"\xe5\x05\n\x11ListMessagesInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\r\n\x05\x61\x66ter\x18\n \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x04sort\x18\x32 \x01(\x0e\x32-.eolymp.discussion.ListMessagesInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.discussion.ListMessagesInput.Filter\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.discussion.Message.Extra\x1a\x80\x03\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08reply_to\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tthread_id\x18\x05 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x33\n\nvote_count\x18\x06 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x34\n\x0breply_count\x18\x07 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x38\n\tposted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"G\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tPOSTED_AT\x10\x01\x12\x0e\n\nVOTE_COUNT\x10\x02\x12\x0f\n\x0bREPLY_COUNT\x10\x03\"N\n\x12ListMessagesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.discussion.Message\"Q\n\x10PostMessageInput\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12\x10\n\x08reply_to\x18\x02 \x01(\t\"\'\n\x11PostMessageOutput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"U\n\x12UpdateMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12+\n\x07message\x18\x02 \x01(\x0b\x32\x1a.eolymp.discussion.Message\"\x15\n\x13UpdateMessageOutput\"8\n\x12\x44\x65leteMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteMessageOutput\"4\n\x10VoteMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"\'\n\x11VoteMessageOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\"-\n\x17ListMessageChangesInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\xd0\x01\n\x18ListMessageChangesOutput\x12\x43\n\x07history\x18\x01 \x03(\x0b\x32\x32.eolymp.discussion.ListMessageChangesOutput.Record\x1ao\n\x06Record\x12\x10\n\x08revision\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x07message\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content2\xd7\t\n\x0eMessageService\x12\xb3\x01\n\x0f\x44\x65scribeMessage\x12\'.eolymp.discussion.DescribeMessageInput\x1a(.eolymp.discussion.DescribeMessageOutput\"M\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x18\x12\x16/messages/{message_id}\x12\x9c\x01\n\x0cListMessages\x12$.eolymp.discussion.ListMessagesInput\x1a%.eolymp.discussion.ListMessagesOutput\"?\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/messages\x12\x9a\x01\n\x0bPostMessage\x12#.eolymp.discussion.PostMessageInput\x1a$.eolymp.discussion.PostMessageOutput\"@\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0b\"\t/messages\x12\xad\x01\n\rUpdateMessage\x12%.eolymp.discussion.UpdateMessageInput\x1a&.eolymp.discussion.UpdateMessageOutput\"M\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x1a\x16/messages/{message_id}\x12\xad\x01\n\rDeleteMessage\x12%.eolymp.discussion.DeleteMessageInput\x1a&.eolymp.discussion.DeleteMessageOutput\"M\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18*\x16/messages/{message_id}\x12\xac\x01\n\x0bVoteMessage\x12#.eolymp.discussion.VoteMessageInput\x1a$.eolymp.discussion.VoteMessageOutput\"R\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1d\"\x1b/messages/{message_id}/vote\x12\xc3\x01\n\x12ListMessageChanges\x12*.eolymp.discussion.ListMessageChangesInput\x1a+.eolymp.discussion.ListMessageChangesOutput\"T\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02 \x12\x1e/messages/{message_id}/changesB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.message_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _MESSAGESERVICE.methods_by_name['DescribeMessage']._options = None
  _MESSAGESERVICE.methods_by_name['DescribeMessage']._serialized_options = b'\202\343\n\033\212\343\n\027discussion:message:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\030\022\026/messages/{message_id}'
  _MESSAGESERVICE.methods_by_name['ListMessages']._options = None
  _MESSAGESERVICE.methods_by_name['ListMessages']._serialized_options = b'\202\343\n\033\212\343\n\027discussion:message:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/messages'
  _MESSAGESERVICE.methods_by_name['PostMessage']._options = None
  _MESSAGESERVICE.methods_by_name['PostMessage']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\013\"\t/messages'
  _MESSAGESERVICE.methods_by_name['UpdateMessage']._options = None
  _MESSAGESERVICE.methods_by_name['UpdateMessage']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\030\032\026/messages/{message_id}'
  _MESSAGESERVICE.methods_by_name['DeleteMessage']._options = None
  _MESSAGESERVICE.methods_by_name['DeleteMessage']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\030*\026/messages/{message_id}'
  _MESSAGESERVICE.methods_by_name['VoteMessage']._options = None
  _MESSAGESERVICE.methods_by_name['VoteMessage']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\035\"\033/messages/{message_id}/vote'
  _MESSAGESERVICE.methods_by_name['ListMessageChanges']._options = None
  _MESSAGESERVICE.methods_by_name['ListMessageChanges']._serialized_options = b'\202\343\n\033\212\343\n\027discussion:message:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002 \022\036/messages/{message_id}/changes'
  _MESSAGECHANGEDEVENT._serialized_start=322
  _MESSAGECHANGEDEVENT._serialized_end=446
  _DESCRIBEMESSAGEINPUT._serialized_start=448
  _DESCRIBEMESSAGEINPUT._serialized_end=556
  _DESCRIBEMESSAGEOUTPUT._serialized_start=558
  _DESCRIBEMESSAGEOUTPUT._serialized_end=626
  _LISTMESSAGESINPUT._serialized_start=629
  _LISTMESSAGESINPUT._serialized_end=1370
  _LISTMESSAGESINPUT_FILTER._serialized_start=913
  _LISTMESSAGESINPUT_FILTER._serialized_end=1297
  _LISTMESSAGESINPUT_SORTABLE._serialized_start=1299
  _LISTMESSAGESINPUT_SORTABLE._serialized_end=1370
  _LISTMESSAGESOUTPUT._serialized_start=1372
  _LISTMESSAGESOUTPUT._serialized_end=1450
  _POSTMESSAGEINPUT._serialized_start=1452
  _POSTMESSAGEINPUT._serialized_end=1533
  _POSTMESSAGEOUTPUT._serialized_start=1535
  _POSTMESSAGEOUTPUT._serialized_end=1574
  _UPDATEMESSAGEINPUT._serialized_start=1576
  _UPDATEMESSAGEINPUT._serialized_end=1661
  _UPDATEMESSAGEOUTPUT._serialized_start=1663
  _UPDATEMESSAGEOUTPUT._serialized_end=1684
  _DELETEMESSAGEINPUT._serialized_start=1686
  _DELETEMESSAGEINPUT._serialized_end=1742
  _DELETEMESSAGEOUTPUT._serialized_start=1744
  _DELETEMESSAGEOUTPUT._serialized_end=1765
  _VOTEMESSAGEINPUT._serialized_start=1767
  _VOTEMESSAGEINPUT._serialized_end=1819
  _VOTEMESSAGEOUTPUT._serialized_start=1821
  _VOTEMESSAGEOUTPUT._serialized_end=1860
  _LISTMESSAGECHANGESINPUT._serialized_start=1862
  _LISTMESSAGECHANGESINPUT._serialized_end=1907
  _LISTMESSAGECHANGESOUTPUT._serialized_start=1910
  _LISTMESSAGECHANGESOUTPUT._serialized_end=2118
  _LISTMESSAGECHANGESOUTPUT_RECORD._serialized_start=2007
  _LISTMESSAGECHANGESOUTPUT_RECORD._serialized_end=2118
  _MESSAGESERVICE._serialized_start=2121
  _MESSAGESERVICE._serialized_end=3360
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/ticket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/judge/ticket.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc6\x04\n\x06Ticket\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12+\n\x06status\x18\x05 \x01(\x0e\x32\x1b.eolymp.judge.Ticket.Status\x12\x0f\n\x07subject\x18\n \x01(\t\x12$\n\x07message\x18\x0c \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x13\n\x0braw_message\x18\x0b \x01(\t\x12\x0f\n\x07is_read\x18\x15 \x01(\x08\x12\x13\n\x0breply_count\x18\x1e \x01(\r\x12.\n\ncreated_at\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07read_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_reply_at\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x63ursor\x18\x64 \x01(\t\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x12\n\x0eMESSAGE_RENDER\x10\x01\x12\x11\n\rMESSAGE_VALUE\x10\x02\"D\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0c\n\x08\x41WAITING\x10\x01\x12\x0c\n\x08RESOLVED\x10\x02\x12\n\n\x06\x43LOSED\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.ticket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _TICKET._serialized_start=103
  _TICKET._serialized_end=685
  _TICKET_EXTRA._serialized_start=555
  _TICKET_EXTRA._serialized_end=615
  _TICKET_STATUS._serialized_start=617
  _TICKET_STATUS._serialized_end=685
# @@protoc_insertion_point(module_scope)



from eolymp.atlas import attachment_pb2 as _attachment_pb2
from eolymp.atlas import code_template_pb2 as _code_template_pb2
from eolymp.atlas import editorial_pb2 as _editorial_pb2
from eolymp.atlas import problem_pb2 as _problem_pb2
from eolymp.atlas import script_pb2 as _script_pb2
from eolymp.atlas import solution_pb2 as _solution_pb2
from eolymp.atlas import statement_pb2 as _statement_pb2
from eolymp.atlas import testing_checker_pb2 as _testing_checker_pb2
from eolymp.atlas import testing_config_pb2 as _testing_config_pb2
from eolymp.atlas import testing_interactor_pb2 as _testing_interactor_pb2
from eolymp.atlas import testing_test_pb2 as _testing_test_pb2
from eolymp.atlas import testing_testset_pb2 as _testing_testset_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Snapshot(_message.Message):
    __slots__ = ["attachments", "checker", "editorials", "interactor", "problem", "scripts", "solutions", "statements", "templates", "testing", "tests", "testsets"]
    ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
    CHECKER_FIELD_NUMBER: _ClassVar[int]
    EDITORIALS_FIELD_NUMBER: _ClassVar[int]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_FIELD_NUMBER: _ClassVar[int]
    SCRIPTS_FIELD_NUMBER: _ClassVar[int]
    SOLUTIONS_FIELD_NUMBER: _ClassVar[int]
    STATEMENTS_FIELD_NUMBER: _ClassVar[int]
    TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    TESTING_FIELD_NUMBER: _ClassVar[int]
    TESTSETS_FIELD_NUMBER: _ClassVar[int]
    TESTS_FIELD_NUMBER: _ClassVar[int]
    attachments: _containers.RepeatedCompositeFieldContainer[_attachment_pb2.Attachment]
    checker: _testing_checker_pb2.Checker
    editorials: _containers.RepeatedCompositeFieldContainer[_editorial_pb2.Editorial]
    interactor: _testing_interactor_pb2.Interactor
    problem: _problem_pb2.Problem
    scripts: _containers.RepeatedCompositeFieldContainer[_script_pb2.Script]
    solutions: _containers.RepeatedCompositeFieldContainer[_solution_pb2.Solution]
    statements: _containers.RepeatedCompositeFieldContainer[_statement_pb2.Statement]
    templates: _containers.RepeatedCompositeFieldContainer[_code_template_pb2.Template]
    testing: _testing_config_pb2.TestingConfig
    tests: _containers.RepeatedCompositeFieldContainer[_testing_test_pb2.Test]
    testsets: _containers.RepeatedCompositeFieldContainer[_testing_testset_pb2.Testset]
    def __init__(self, problem: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ..., testing: _Optional[_Union[_testing_config_pb2.TestingConfig, _Mapping]] = ..., checker: _Optional[_Union[_testing_checker_pb2.Checker, _Mapping]] = ..., interactor: _Optional[_Union[_testing_interactor_pb2.Interactor, _Mapping]] = ..., statements: _Optional[_Iterable[_Union[_statement_pb2.Statement, _Mapping]]] = ..., templates: _Optional[_Iterable[_Union[_code_template_pb2.Template, _Mapping]]] = ..., attachments: _Optional[_Iterable[_Union[_attachment_pb2.Attachment, _Mapping]]] = ..., testsets: _Optional[_Iterable[_Union[_testing_testset_pb2.Testset, _Mapping]]] = ..., tests: _Optional[_Iterable[_Union[_testing_test_pb2.Test, _Mapping]]] = ..., editorials: _Optional[_Iterable[_Union[_editorial_pb2.Editorial, _Mapping]]] = ..., solutions: _Optional[_Iterable[_Union[_solution_pb2.Solution, _Mapping]]] = ..., scripts: _Optional[_Iterable[_Union[_script_pb2.Script, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.judge import activity_pb2 as _activity_pb2
from eolymp.judge import contest_pb2 as _contest_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CloseContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class CloseContestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CopyContestInput(_message.Message):
    __slots__ = ["contest_id", "copy_name", "copy_scope", "copy_visibility"]
    class Scope(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: CopyContestInput.Scope
    CONFIGURATION: CopyContestInput.Scope
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    COPY_NAME_FIELD_NUMBER: _ClassVar[int]
    COPY_SCOPE_FIELD_NUMBER: _ClassVar[int]
    COPY_VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS: CopyContestInput.Scope
    PERMISSIONS: CopyContestInput.Scope
    PROBLEMS: CopyContestInput.Scope
    contest_id: str
    copy_name: str
    copy_scope: _containers.RepeatedScalarFieldContainer[CopyContestInput.Scope]
    copy_visibility: _contest_pb2.Contest.Visibility
    def __init__(self, contest_id: _Optional[str] = ..., copy_scope: _Optional[_Iterable[_Union[CopyContestInput.Scope, str]]] = ..., copy_name: _Optional[str] = ..., copy_visibility: _Optional[_Union[_contest_pb2.Contest.Visibility, str]] = ...) -> None: ...

class CopyContestOutput(_message.Message):
    __slots__ = ["copy_contest_id"]
    COPY_CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    copy_contest_id: str
    def __init__(self, copy_contest_id: _Optional[str] = ...) -> None: ...

class CreateContestInput(_message.Message):
    __slots__ = ["contest"]
    CONTEST_FIELD_NUMBER: _ClassVar[int]
    contest: _contest_pb2.Contest
    def __init__(self, contest: _Optional[_Union[_contest_pb2.Contest, _Mapping]] = ...) -> None: ...

class CreateContestOutput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class DeleteContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class DeleteContestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class DescribeContestOutput(_message.Message):
    __slots__ = ["contest"]
    CONTEST_FIELD_NUMBER: _ClassVar[int]
    contest: _contest_pb2.Contest
    def __init__(self, contest: _Optional[_Union[_contest_pb2.Contest, _Mapping]] = ...) -> None: ...

class DescribeContestUsageInput(_message.Message):
    __slots__ = ["period_end", "period_start"]
    PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    PERIOD_START_FIELD_NUMBER: _ClassVar[int]
    period_end: _timestamp_pb2.Timestamp
    period_start: _timestamp_pb2.Timestamp
    def __init__(self, period_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DescribeContestUsageOutput(_message.Message):
    __slots__ = ["active_contests", "monthly_contests", "total_contests"]
    ACTIVE_CONTESTS_FIELD_NUMBER: _ClassVar[int]
    MONTHLY_CONTESTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_CONTESTS_FIELD_NUMBER: _ClassVar[int]
    active_contests: int
    monthly_contests: int
    total_contests: int
    def __init__(self, total_contests: _Optional[int] = ..., active_contests: _Optional[int] = ..., monthly_contests: _Optional[int] = ...) -> None: ...

class FreezeContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class FreezeContestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListActivitiesInput(_message.Message):
    __slots__ = ["contest_id", "offset", "size"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    offset: int
    size: int
    def __init__(self, contest_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListActivitiesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_activity_pb2.Activity]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_activity_pb2.Activity, _Mapping]]] = ...) -> None: ...

class ListContestsInput(_message.Message):
    __slots__ = ["filters", "offset", "search", "size"]
    class Filter(_message.Message):
        __slots__ = ["city", "country", "difficulty", "ends_at", "featured", "format", "id", "name", "public", "region", "scale", "series", "starts_at", "status", "visibility", "year"]
        CITY_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_FIELD_NUMBER: _ClassVar[int]
        DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
        ENDS_AT_FIELD_NUMBER: _ClassVar[int]
        FEATURED_FIELD_NUMBER: _ClassVar[int]
        FORMAT_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PUBLIC_FIELD_NUMBER: _ClassVar[int]
        REGION_FIELD_NUMBER: _ClassVar[int]
        SCALE_FIELD_NUMBER: _ClassVar[int]
        SERIES_FIELD_NUMBER: _ClassVar[int]
        STARTS_AT_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        VISIBILITY_FIELD_NUMBER: _ClassVar[int]
        YEAR_FIELD_NUMBER: _ClassVar[int]
        city: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        country: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        difficulty: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        ends_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        featured: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        format: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        public: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        region: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        scale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        series: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        starts_at: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionTimestamp]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        visibility: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        year: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., starts_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., ends_at: _Optional[_Iterable[_Union[_expression_pb2.ExpressionTimestamp, _Mapping]]] = ..., public: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., visibility: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., format: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., featured: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., year: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., scale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., series: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., difficulty: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., country: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., region: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., city: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListContestsInput.Filter
    offset: int
    search: str
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListContestsInput.Filter, _Mapping]] = ...) -> None: ...

class ListContestsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_contest_pb2.Contest]
    total: int
    def __init__(self, items: _Optional[_Iterable[_Union[_contest_pb2.Contest, _Mapping]]] = ..., total: _Optional[int] = ...) -> None: ...

class OpenContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class OpenContestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ResumeContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class ResumeContestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SuspendContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class SuspendContestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateContestInput(_message.Message):
    __slots__ = ["contest", "contest_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateContestInput.Patch
    APPEARANCE: UpdateContestInput.Patch
    CONTEST_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    DURATION: UpdateContestInput.Patch
    ENDS_AT: UpdateContestInput.Patch
    ENVIRONMENT: UpdateContestInput.Patch
    FEATURED_UNTIL: UpdateContestInput.Patch
    FORMAT: UpdateContestInput.Patch
    JOIN_UNOFFICIALLY: UpdateContestInput.Patch
    KEY: UpdateContestInput.Patch
    LOGO_URL: UpdateContestInput.Patch
    NAME: UpdateContestInput.Patch
    PARTICIPANT_COUNT_HIDDEN: UpdateContestInput.Patch
    PARTICIPATION_MODE: UpdateContestInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_HIDDEN: UpdateContestInput.Patch
    SCOREBOARD: UpdateContestInput.Patch
    STARTS_AT: UpdateContestInput.Patch
    TAXONOMY: UpdateContestInput.Patch
    UPSOLVE: UpdateContestInput.Patch
    VISIBILITY: UpdateContestInput.Patch
    contest: _contest_pb2.Contest
    contest_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateContestInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateContestInput.Patch, str]]] = ..., contest_id: _Optional[str] = ..., contest: _Optional[_Union[_contest_pb2.Contest, _Mapping]] = ...) -> None: ...

class UpdateContestOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class WatchContestInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class WatchContestOutput(_message.Message):
    __slots__ = ["contest"]
    CONTEST_FIELD_NUMBER: _ClassVar[int]
    contest: _contest_pb2.Contest
    def __init__(self, contest: _Optional[_Union[_contest_pb2.Contest, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/runtime/configuration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*eolymp/runtime/configuration_service.proto\x12\x0e\x65olymp.runtime\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\x1c\n\x1a\x44\x65scribeRuntimeConfigInput\"6\n\x1b\x44\x65scribeRuntimeConfigOutput\x12\x17\n\x0f\x61llowed_runtime\x18\x01 \x03(\t\"6\n\x1b\x43onfigureRuntimeConfigInput\x12\x17\n\x0f\x61llowed_runtime\x18\x01 \x03(\t\"\x1e\n\x1c\x43onfigureRuntimeConfigOutput2\xee\x02\n\x14\x43onfigurationService\x12\x99\x01\n\x15\x44\x65scribeRuntimeConfig\x12*.eolymp.runtime.DescribeRuntimeConfigInput\x1a+.eolymp.runtime.DescribeRuntimeConfigOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x12\x12\x10/configs/runtime\x12\xb9\x01\n\x16\x43onfigureRuntimeConfig\x12+.eolymp.runtime.ConfigureRuntimeConfigInput\x1a,.eolymp.runtime.ConfigureRuntimeConfigOutput\"D\x82\xe3\n\x19\x8a\xe3\n\x15runtime:runtime:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\x1a\x10/configs/runtimeB1Z/github.com/eolymp/go-sdk/eolymp/runtime;runtimeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.runtime.configuration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/runtime;runtime'
  _CONFIGURATIONSERVICE.methods_by_name['DescribeRuntimeConfig']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['DescribeRuntimeConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\022\022\020/configs/runtime'
  _CONFIGURATIONSERVICE.methods_by_name['ConfigureRuntimeConfig']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['ConfigureRuntimeConfig']._serialized_options = b'\202\343\n\031\212\343\n\025runtime:runtime:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\022\032\020/configs/runtime'
  _DESCRIBERUNTIMECONFIGINPUT._serialized_start=161
  _DESCRIBERUNTIMECONFIGINPUT._serialized_end=189
  _DESCRIBERUNTIMECONFIGOUTPUT._serialized_start=191
  _DESCRIBERUNTIMECONFIGOUTPUT._serialized_end=245
  _CONFIGURERUNTIMECONFIGINPUT._serialized_start=247
  _CONFIGURERUNTIMECONFIGINPUT._serialized_end=301
  _CONFIGURERUNTIMECONFIGOUTPUT._serialized_start=303
  _CONFIGURERUNTIMECONFIGOUTPUT._serialized_end=333
  _CONFIGURATIONSERVICE._serialized_start=336
  _CONFIGURATIONSERVICE._serialized_end=702
# @@protoc_insertion_point(module_scope)
